@@ -20,12 +20,14 @@
 
 enum { MAX_ROWS=1000 };
 
-extern long int totalsize, sectorsize;
+extern long long int totalsize, sectorsize;
 extern GList *exclude_pattern_list;
 extern int selected_files[MAX_ROWS];
 
 extern GtkWidget *total_size, *exclude_pattern_combo, *clist, *exclude_dir;
-extern GtkWidget *mkisofs_follow_symlinks, *mkisofs_include_all, *mkisofs_include_dirname;
+extern GtkWidget *mkisofs_follow_symlinks, *mkisofs_include_all;
+extern GtkWidget *mkisofs_include_dirname;
+extern GtkWidget *path_default_level_sb, *path_default_from_end;
 
 void mark_size_inaccurate(void);
 gint resize_clist_col_ratio(GtkWidget *, GdkEvent *, gpointer);
