@@ -31,7 +31,7 @@
 #include "locks.h"
 #include "globals.h"
 
-static GtkWidget *opt_try_harder;
+GtkWidget *opt_try_harder;
 
 static GtkWidget *cdsize_option_menu, *cdsize_selected_label, *cdsector_selected_label;
 static GtkWidget *used_size_label, *used_sectors_label, *wasted_size_label, *wasted_sectors_label;
