@@ -20,6 +20,7 @@
 #include <sys/time.h>
 #include <unistd.h>
 
+#include "generic_output_handler.h"
 #include "locks.h"
 #include "linebuffer.h"
 #include "readers.h"
@@ -35,9 +36,15 @@ static cmd_v *cdrecord_audio_track_nofix, *cdrecord_fixate;
 
 static int track_now, total_tracks, cdda2wav_burn;
 
+/* TODO: these (and the functions using them) should be moved to a new file
+ * when the great restructuring is done */
+static two_pipe_handlers mkisofs_pipe_handlers;
+static pipe_handler mkisofs_stdout_handler;
+static pipe_handler mkisofs_stderr_handler;
+
 /* functions for make_image_only */
 
-static void close_mkisofs_f(int *fd) {
+static void close_mkisofs_f(void) {
 	if (misc_prefs.own_progresswin) {
 		gtk_widget_destroy(progress_win);
 		progress_win = NULL;
@@ -97,24 +104,46 @@ static int wait_mkisofs_output(gpointer data) {
 	if (!(stdout_ok || stderr_ok)) {
 		wait_pids();
 		stdout_ok = stderr_ok = TRUE;
-		close_mkisofs_f(fd);
+		close_mkisofs_f();
 		return FALSE;
 	} else
 		return TRUE;
 }
 
+static void mkisofs_done(void) {
+	wait_pids();
+	close_mkisofs_f();
+}
+
+static void initialize_mkisofs_handlers(int *fds) {
+	mkisofs_stdout_handler.fd = fds[0];
+	mkisofs_stdout_handler.callback = ni_read_mkisofs_stdout;
+	mkisofs_stdout_handler.status = TRUE;
+	mkisofs_pipe_handlers.ph1 = &mkisofs_stdout_handler;
+
+	mkisofs_stderr_handler.fd = fds[1];
+	mkisofs_stderr_handler.callback = ni_read_mkisofs_stderr;
+	mkisofs_stderr_handler.status = TRUE;
+	mkisofs_pipe_handlers.ph2 = &mkisofs_stderr_handler;
+
+	mkisofs_pipe_handlers.end_callback = mkisofs_done;
+}
+
 void open_mkisofs_progress_bar(int *output) {
 	cdda2wav_burn = FALSE;
 	open_progress_win(_("Making image, please wait."));
 
 	init_buffers(BUF_MKISOFS_STDERR | BUF_MKISOFS_STDOUT);
 
+/*	initialize_mkisofs_handlers(output);
+	gtk_timeout_add(TIMEOUT_GTK, handle_output, &mkisofs_pipe_handlers); */
+
 	gtk_timeout_add(TIMEOUT_GTK, wait_mkisofs_output, output);
 }
 
 /* functions for burn_from_image only */
 
-static void close_cdrecord_f(int *fd) {
+static void close_cdrecord_f(void) {
 	if (misc_prefs.own_progresswin) {
 		gtk_widget_destroy(progress_win);
 		progress_win = NULL;
@@ -173,7 +202,7 @@ static int wait_cdrecord_output(gpointer data) {
 	if (!(stdout_ok || stderr_ok)) {
 		wait_pids();
 		stdout_ok = stderr_ok = TRUE;
-		close_cdrecord_f(fd);
+		close_cdrecord_f();
 		return FALSE;
 	} else
 		return TRUE;
@@ -190,7 +219,7 @@ void open_cdrecord_progress_bar(int *output) {
 
 /* functions for make_image_and_burn */
 
-static void close_mkisofs_cdrecord(int *fd) {
+static void close_mkisofs_cdrecord(void) {
 	if (misc_prefs.own_progresswin) {
 		gtk_widget_destroy(progress_win);
 		progress_win = NULL;
@@ -273,7 +302,7 @@ static int wait_mkisofs_cdrecord_output(gpointer data) {
  * user, the current redirection hack doesn't seem to recognize an abrupt kill() */
  		if (bailed_out) {
 			iso_stderr_ok = cdr_stdout_ok = cdr_stderr_ok = TRUE;
-			close_mkisofs_cdrecord(fd);
+			close_mkisofs_cdrecord();
 			return FALSE;
 		} else {
 			return TRUE;
@@ -342,7 +371,7 @@ static int wait_mkisofs_cdrecord_output(gpointer data) {
 			}
 			gtk_timeout_add(TIMEOUT_GTK, wait_mkisofs_cdrecord_output, output);
 		} else {
-			close_mkisofs_cdrecord(fd);
+			close_mkisofs_cdrecord();
 		}
 		return FALSE;
 	} else
