@@ -41,7 +41,7 @@
 char *cdda2wav_path = NULL, *cdda_device_path;
 char *def_rip_path = NULL;
 char *cdparanoia_path = NULL, *cdpara_device_path;
-static GtkWidget *rip_path_entry;
+GtkWidget *rip_path_entry;
 
 static GtkWidget *rip_win = NULL, *p_win;
 static GtkWidget *autoscroll_cdda2wav_text, *cdda2wav_text, *cdda2wav_text_scrollbar;
